summaryrefslogtreecommitdiffstats
path: root/src/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/main.cpp b/src/main.cpp
index 0e291ee..81b73e8 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -70,11 +70,11 @@ class Application : public KUniqueApplication
int main(int argc, char *argv[])
{
// KCmdLineArgs::init will modify argv[0] so we remember it:
const char *argv0 = (argc >= 1 ? argv[0] : "");
- KCmdLineArgs::init(argc, argv, Global::about());
- KCmdLineArgs::addCmdLineOptions(basket_options);
+ TDECmdLineArgs::init(argc, argv, Global::about());
+ TDECmdLineArgs::addCmdLineOptions(basket_options);
KUniqueApplication::addCmdLineOptions();
//KUniqueApplication app;
@@ -86,12 +86,12 @@ int main(int argc, char *argv[])
MainWindow* win = new MainWindow();
Global::bnpView->handleCommandLine();
app.setMainWidget(win);
-// if (!(Settings::useSystray() && KCmdLineArgs::parsedArgs() && KCmdLineArgs::parsedArgs()->isSet("start-hidden")))
+// if (!(Settings::useSystray() && TDECmdLineArgs::parsedArgs() && TDECmdLineArgs::parsedArgs()->isSet("start-hidden")))
// win->show();
if (Settings::useSystray()) {
// The user wanted to not show the window (but it is already hidden by default, so we do nothing):
- if (KCmdLineArgs::parsedArgs() && KCmdLineArgs::parsedArgs()->isSet("start-hidden"))
+ if (TDECmdLineArgs::parsedArgs() && TDECmdLineArgs::parsedArgs()->isSet("start-hidden"))
;
// When the application is restored by KDE session, restore its state:
else if (app.isRestored())
@@ -70,11 +70,11 @@ class Application : public KUniqueApplication
int main(int argc, char *argv[])
{
- // KCmdLineArgs::init will modify argv[0] so we remember it:
+ // TDECmdLineArgs::init will modify argv[0] so we remember it:
const char *argv0 = (argc >= 1 ? argv[0] : "");